<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/fp-wien/assets/banner3.png */
class __TwigTemplate_9a6e84d9ad3bfd1f64958c7274e78e5c extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000^\000\000\000\000\000)\000\000\000tEXtSoftware\000Adobe ImageReadyqe<\000\000(iTXtXML:com.adobe.xmp\000\000\000\000\000<?xpacket begin=\"﻿\" id=\"W5M0MpCehiHzreSzNTczkc9d\"?> <x:xmpmeta xmlns:x=\"adobe:ns:meta/\" x:xmptk=\"Adobe XMP Core 7.2-c000 79.566ebc5b4, 2022/05/09-08:25:55        \"> <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\"> <rdf:Description rdf:about=\"\" xmlns:xmp=\"http://ns.adobe.com/xap/1.0/\" xmlns:xmpMM=\"http://ns.adobe.com/xap/1.0/mm/\" xmlns:stRef=\"http://ns.adobe.com/xap/1.0/sType/ResourceRef#\" xmp:CreatorTool=\"Adobe Photoshop 23.4 (Macintosh)\" xmpMM:InstanceID=\"xmp.iid:807F44B3873311EE9C22FAB5E60E0DC4\" xmpMM:DocumentID=\"xmp.did:807F44B4873311EE9C22FAB5E60E0DC4\"> <xmpMM:DerivedFrom stRef:instanceID=\"xmp.iid:807F44B1873311EE9C22FAB5E60E0DC4\" stRef:documentID=\"xmp.did:807F44B2873311EE9C22FAB5E60E0DC4\"/> </rdf:Description> </rdf:RDF> </x:xmpmeta> <?xpacket end=\"r\"?>og\000\000\000PLTE\tY䫻u琟ҸfUd-W6f
a\\d(dUcvfd[IlrvWEyx7u)2dfYIt\\'iLP0ykoHe]h3j(sYyR[ǲdzw-u;pEbpjf8Q\\cy,3rvaD)]|~ORCjg҅lfobtՃym<e`cL 3j`lkH{߬V^d<@rba<\$aPO^i]IhTCaKܔQL`
\\R|~aaCk덿g pe-p_ڊVeS[bJec`_`fhjو1kUM!hnܠe򕼑\000\000>IDATx@g2\"60*b(HZE*bZ]#[͗Y7kk[l[k4ۭg[ztp\$`5Nh[ܾOg'G0\t 8ŏQ7xTdb.Z㽷
x1^l/Ƌbx1^Ƌb0^Ƌb0^ņb/6ņb/6xa/Ƌ
x1^l/Ƌ
x1^l/Ƌbx1^Ƌbx1^Ƌb0^ņb/6ņb/6xa/Ƌ
xa/Ƌ
x1^l/Ƌbx1^l/Ƌbx1^Ƌb0^ņb0^ņb/6xa/{_I
.!\tI=R{|w|ey7 IR^\$\"H^xɠR&A'{%o*9Ij%VITA}_7t^9aZ)x\\bmj:h1;Q
佺^Z\tHL\"RMxr3IwrR`p4KWHD\"'L
v{͢3y޽5Tz\$*N+oWlHI}F.^Tew`жK)Q*KťJդeJRI KIߐyu;^4:b[U3GuYOSf_X{z+5vrņjKJԨ&^͒~KMxF#UvY\\vҙSO.pV)c4j4T\"w
+&RdEEP@nzYnm|a<nJ_T_?vdɕ*Tz\"mEZB޽v/M4!A{6x!4ڄ
nwmku6؁7(k,jDEEu5\"\"=ԊLV奊/pתVQPl\\Jۙo84s(6&8=v̌l
N4߳gAck_EAYk2ɉݴAZVxp45))e_ڃç 1^˴N][+ w/x\$*\"Lv\$%MԺ,^0U.dk-AjY_xꘪFAQԤx9&L_`T1ݜtj3Qb(h|mmmp
uq͛/>S.2>Lҩ[Svb ??5Eu{ \\,S(v\000B))%))y1*K4s×WU2\tt齝\$¿O%DX某e2Es'\000`---BP|Óh>uLNyޓw9O/W^[E7H>/P|mvn;gNnp]Mfh'h[nP
n+f͆x߭V)fIj̍^;lvq2ii\t/NQviqrl]{OEi䢤&ut̙31%Ed;^IUA분* OA (\\^6!O`?oo޹>܃xABebiv17m@BPAx5VF#0)zA sA_g6\\ϜΖu0MN4\trO1iH}w܏Z5Ig2A\000d\\yQ85\$*>~W8@~o߾vZ#.> )/\t/e&2Ig55M**(X8I.fVM%Fp'^ke4㉘iBx4HakujѬ6Q%^}u큸UCD&FȰ_olƯenP9h(Za9MhI.c<Sf~rOmmv.cMvv<jɕ_bQ;:/!5yeU
4MZh^\to\\.(.W%H6ވ-4#АAhKs@'M#яnPt:[-3Lp!r|(GSSֆ&ĝ'\\bf36,imu.Ow2~Ǻ^FF{|\\Wr\\\\&!n7äEp~W14,ufffN(\000gZinFxB[D80ir}8]~Я5O3vbϏCQC
iؿ#PdӔf\"K6JDH\$ڻ]k^t)]EQl',>?w3pd^\\
aA\"CTBN`\"ɑ#G*#Z92ADBHbBj9XzdP>[\tNL&43 ҄\000ЌLtcS.[inLc#AEɋY[(DZ+Iʕ=FE(rBb2Y\"#
SP@4*TYVVkJ
x!H̤dBQVɠ5r9gPf\000|I+ۉW:ųvqj\$\"(%=/!WkmI6N.lr@HJ\$!0*TZl (WjJiK䄒 4j}N
ߗ0&B
@Cnʜ|]]@t+r)%Ԣ !S .钒X(KWwV[#T!HB)_@`،J]!cG,^Qr\000^Fxo;)w)c\\B*=\000%*.J=q`qEqqq#=ݒكN¹e芢=q{I4JՑ#j޽
\"|* kmmF;qۄMK%fN}}

'{V~/g<B/أª^gs8rSg\\(MM2(9s)ԷS'mS[P.?\"қ{d ͆)ӧO_<>=:|Apt`ღt/_<N
]=hYˣ3x\t4<_Yٻw<eͳ7wxY0_(Dd<GEAx\"X=1֭E\"{C=GƅoUС׶_5w\t/<z݊5YuZf[[Mg?M/x|7b{ӐQC?_TAhEZek/CUS]TŨQQ&sS__J`;\"{\\~Tj4F]zlힰuy4t,@ъ}
E
W?C'*@d(ZUXϹԚʞN'PxMT-| HAC*LI)\\}[
8Ԣ;?5@*
,t҄^ [^/HMM^6\\,SHpQCOw/2~}_{xY\"6_ni#7qʘ&NNUU+&
?7;;;nQD-*Y*/Z3`QA\"\\[x>QU%Y:i]A(}v|o~}7<|MT?Ov𻻧d3ö0v=2HJD6\$VS>ssW%\tcJ£˷0S^+>PyeyΏt7oQ[8ىחӯ~6<g6p45|hC?d=_}7~(^ZA:\000bg\\/۵WңB[{3&>VAb.N,qO,x2:rG0`\t

R)ͭ+Sm;8)HOO@xK!}:P*})x~/
3gӌa6uX36ZDkC*,cE[ჃC1TѬ}EE%J:wʂsJnZ4lY|!d߇4I`?!>eoxgn[IC9*\000v\\#zS݌uʨUYɻ8{
ٹf/G]1r\\seM/ɻM>e-t߆_?[(׾*CGN
zo/VԱ6-(xs5Nywk(ʈ[9 ll>୳ڐ\$7|ib<}9vCC/Nx<lN?v@q*G|/;]Dٲ
uː-9[KhY]&ЇoYZtqKxQ!
)J];_4:=pM
fKjIJ1Uѫ֏>*GiǛ!c@>g09v.{ڝK;]x\000x7!^
/;PsA#Cj/6}ĨZ<\000|sߘrlދƜ(10N{?xÆy֜NŻkW}_1D5XG-{{{iFW|
NYxxAҜ5}{\\O>;>C_P~>e@xrdPrh/J!ɰ*zB)/:leu/
ɣ{5!6NqZ̤c?Nց)~Eڏ~}1w[m)\$2O^KubZ+藯rl}X'5\t]%P&C7 /Rvo<8W7<|b0h=/klko
ڛ*\tjkɣ!XO
CF=youYS06!͇:}7p\\.4ۯ>
׮3o5&ҽ!O>Q2</-Z'P
{0\$f\\o\"P 0.>s}bnu9!ox\000 lu4xS]x/9:V5\0008tz~Qo
=^g/:j:\th՚
\t&!\000\\C^{_vNJSˆԉwïޟ
G1.wOw2ˬ\"3!Fן;#ll;nǎ^E˸m>\";F{5si+&&UW_w؀q8jo뤢+٩O -s2\\2Ϳu}V;2C:ѡPTswtӌAӝ}\t^6Ν)4ĺjT
Mհx-PP4<rrttXG>7;3ٿyo!Zك\0004o\t{; \000)c9u
wBaS6g9\\Of@t/UmK⮤pu\"^DXECv]DdU'j'>'vN5:\$KxY!@x.f敔DѰz0ޯdi
O5\$Bh׬U.W&J'M>|]
h>wޮ߆41Na&_{i:Ðz[Bd\000:Ig3Y\"M\\tQsx/f&&I{O7HT.6gÕeqq\\-((x]F֥({wཇ~oO:.]x;Ez]''7&&ܙQxrV^tG/
\\<#jq҂#%hkZ#[`1
bVo|`3fXȢ\tQS礉ā^{cKte_^bp
{j#0Gy]BvS-b|r8흷rnĿ(5&s
ē_-&e]Bhp>\\{Q[UkȖef\t,^⽌^xU/vیnv`!PNY련vm/E&6ZELޖx޲FrijjFHgI{;o_zs^Ʌ,u/UWh;
[9Qg,̔jԩyQw qm>~Cxn2шΠŰmms>.άVl6Hk*~^tN';lǫVj*R4N=(1۫jvtbx_`YFѬ13
iKOmx)dn&SS3Us7kTrjPd\"\"3jH/O)I6KLP\$ 7-wlWdYj@V6!k\\˾Z4ハ^ےp\"Q#WZkiΦcߗ|9i>3\tc˞5:_̝;9L+h;#9l3l}/N\tOLJBn_6Hx
&,I&tJFz:\tG{rͭv\"NxŒ\$Ȗhz/J
pբaQ?o\000s#3jEJaKڛn#tZ#
<Ȏ-nǎ?;vlc?,%'dRtdbeљ(=sq+Zk%Iϫ\$G.Ws
~B;i4Ec'vxʼP3m܀,U*RKqH4Tg{<
QM6AVIC_׭߫}yd_tW^Y-zUY(Nm\\˾;pVΔܒ|umVJe2/d3\tӌ:zF\000M!K.\t
[Y!՘3ז,*GUsY)Tĭ+Cv47N=vcv\$)(Dex7`FųY;^hT>x(X!ZbLznbuVg44XC#dP'}4\tmڠ:جxrqT{4IvvFaLu
f4K'
L\$o##zcΧigtf}7x_l.3VGCˇ*-}Xނb[[@WwŴ|FX[ep-=`%\000aEe|JQE=/x\$բ֬)̜o?j%zL|ŋ+0-Qé +dت?.&XXjL.mqڧ}35-nAqXPs]~\"d\\+~z'!e.=
{Bc>j\"=!_.14rz^Zsdg7\$ϯfPZͤ>IY:>(%&>!6cKƄ3x9)4 q*h/ʋ</N%>R-NAQќjʄ
MFo9WOX\\;J|奸rUyF=~/aiS,V>/ܾIc8S69\$oiH}[uV(xHN:>\"-_YFx͉Rif<F*adcHu
#{Z<`IIO!*}ml򏬭m|Y)zݐ|GX6(dǢB?uy\tR#5isq8Rp1uAjvda*Vɉ#(sh)~΢\t_+4UږP7Ѽ2&F8#E/9㣽}ؾ?7rw=>@4}=mwkշO^/!94GʜQE
yipYߨ!7
1}P3eVoBxg=R p8Vwhe7YʶuEG#׌IZ5a;}]1dKOmn_eh1' [\t>^tY-x=+%vǡEWZ[1K<
¡E,zrFQ>+U\$Ae@=p1h/lټ|\\sCKAt0ό\t37~໼Ph\tWϣ_ N
yc#·2{3?><E:O\"?N:fBH2?O>\t|U-(gko~#7kqOMVjVOq@EXM\$ABx-(4>\"\\Fc?\\Y`-EA`ƺyZ\000-dw9 ƻ~[:|l{ap<p{t{9[9KS9SW8`:t|iZ`qq1w'#歿:rj(j42YRU%d&Q.㪍WVŧ-\000N/6<\"|n@PzN*5nov(rԆrqZLDlٍ2#Q9qs\\/ZjX8`wtwr>aheeeR%D֗Hn8=L,?Y</\000?\\/
YWL}gFLVċEAFJTAs<N;kNk4qƾSgʢHR
\$ǋ3LD7/{#M@FsC!ųo})4B;''wWD|57'Q,
߳
~T|bt/lFFm.ГrE91N7x.@⒱.{>`{;>:'<T^|ݾ?jib|:3n!SDįs^{O'x G7pWv{3U*sҁ/ꠍWf=nH´OhgC佺`vnay\000mnw\000*K1fȭ|o=?88.؃o\000g/t7atoRO|޾|\t@ğJ{Ŷ]\t&;1nebV>t:(~Ռ+[o;<4@&hRUHDj4OTmAtaaчb\"\"brL޽ǌ\000GzIMUu^ȃġnG7s  zw~K/OGquJ_Ќpueq8#~[#|_K/cW)ʓ9}FH\$=1|/VGlC{rNzb9S̙ڜЁݧdOa_͉so6݆@<o޿O^!->Gk+h\$xtWoN'|'ۄ
![5Mr%X{LhSˍy_kL-@N'cG[2~WKs7;
Bx~gn7\t!GG!<R/F_w65\t
{h^BUsлZ2\$vȐMP7e#)͊JݍMMU7Na(:=Z,A𣍺AQAM)B\$\$fҙUE(wb:-
b/;mV )&fۨЭOyA=nt94>{g,re1w+ځ|q!ɹ#4e^!*JL^
``Cc\$AAh9VBPz樈`[M^'hjb֦i;\$.>\"v CK!ljynLvv\"@Ȥ8vco-:ʫlݪ2)WB;Sy@g;%ǽ/t,ñ\"ܬL^tJBHtT\t~vZ𢍳[ZIp\tub*^P2=EB:\"r7&lCSUW'UO)+Z={(]]=8+F b+F\$Eڠ#n 4,Iw:G
=^/ew4,mvomK1N3U\\srBxw3cK`ʖ1GO+/wQfbY3WƗp!29ho˷sMDV!'*T[0˧Nt4[hSn%|t;^v|hs\000_z\\]R.Ń_Hfʆr<ܵ79ؾhx&!xxYZ}=ՊnTԃ\000\$e!17[:֜Cj*AN)28-mjCf}Kmg-U2\\\\(
o~QT=_?7GDp},zi=H1=<^6[:#<`jd2?/[bK-h=DGe
6EShg `oL)ٙΧ^M=ѯ+*z:꟫r?wg\\hN35 N<+Y !ڜ)P#=;QZhx*s]^}
!NNHÖ;;ztI|o[ħ.E'GPPD]PRmmyƖGvv
^\$
waLw{E\"SP+Ԙ5ZH?UAYABQ؈%3g\\vA5(81鋗-u\000^Kt33YioKC
K&sL#mͫGhh4QGiW%jBΙgh-vx;:~IѡΙ
6'%9bo{Gܪ6k.\\n'ocsiq/A+32!xeFF0贴܏74L쵫V z=4Z%+\")EQO!8W\"pv+kE2*Ct^Dq[2k虛N+F@oǫ\000P8k\000g=%_7ʄHbz_4ޱxi>=F5;nx;omJr\$q2=7@eisƿ>iDTߵ~݀oPћ7>uӣܼyaaGJ!gǷnz~ncse2q^,ivo-bKsQbYfL6cυdNHQE~c}X%
*D|mIDd\000~ɖYo𶴤%-3s+<3rʕO>jf>}]|n1q}c\\zsQu(Fm'!-!:Z^m5\\m\t,ы&&i#8SZƀG.,,<MSRotyxr2CS-S3jEpzƏ-~-{ns[K'o6\tQ+?8
W>j΅ӓ>\000TA-q
5y7*xm«*d%\tqk¶jV`}wo.G2r)tt!)FnIه߂qs+'=~`+e/>#P1DN/zu \\\000OJȸ86HDJ#-]}@YׄHU~]6h,_7x֬2͛CXxGN?,?dɈGb4%͸7޾y_IqEn)=`Sb4̺ARC!juHBOFjqmv=]RU\${3ʓ1|Wሰ\tro\000\$<QbeUj\000
.,^p6.{>--
ع㏌UVUr1qn#dC/(wCRyc@XsqcWt!?ې.#w\\]{vEB9aou\\j)(xN)R]S@Ql.MYpOW\000˫\\Rx.MH+X)Yuߎڝz\000]Eah7qFT+EcC.xX_@\taGö9fћΣHvCec\$ňxN)hBع{n*Q(V8GRX.涕H5r%E@ys޻}BAZg^x7-qEh.Ï)ѳsZ'ݠ\000:-s:efhJxH\\CaJej//d\$\$e=ڀR.wl#ܴF=Pg;vQqF(D@wH)c S7l1\"-{ݽ
oܦ&alI=]XiSJع6uû96!R
7/qgv1pAw/gFͥc#K^]5WMƶiI:(22_)U6!1潈s)aO!Y{рnRqGk64n|x]9\"0k\\T
x jl&OL|4MP )Zw7Q
_ޅ<ȋ=TLQ\t\\q8==/-=U,.Y\$OJs(*P \tg6IOWsٺ?6ھ`7,p4h3\\}nȑg-U~&M,ܷkX7f>YX
>bSQ PMAä;!
a
J[Ʀ\"@n/#p=qJ\"bbeEt&:~+`GWfń'<gOߞGpZZM{/iZMwHYb@s?eSʦa'Ye³Չ罳J\$MP4~ӳ=@>
WPvF3zCk9w΀M#\$%\tl&BNǧ2u<~I=jSdjT
SX/;D
Ra!G7mR-pդ']Tge΋tq|^1ꪡظSN+׎k64UMgL`l tQv#j %M76yBJ{g)a!?ɧ?>BL`ѨT*W{-ߙ֔/߭Z4F8|on+4?|±h\"d;6?°O6E&=i9s)-P\\2rĈڎ^r?@Nr͵:.VyIRVjԨ1Y]*?dILLlYhs4|քB+dG|09郤Hs&Aʟ5I)6L,\\pU!Ryv2q! 3F8siV<Bj՛\"!5*hf&^Yg
n6fW&ch!
x|mrKӪ%
\\>K#xMVm:iGl9sGܟz39y,JP2pޔEE
Z}%:j;VK*ED`V>^z3Veee1hlcA!qlx TdZ:|1|Krtwޚf4MySIbS鳻@(1ʭw+@z/U\\DAŋ&h;ܤUE\"V.p
s
89S&}SrVGX,5ljAH0Vk֋Jeдflohi`7{x\\2eA!x<+.^R^ЁM@k2iDmtG=rd4yYIôm߾:ia<o1֠NwGHuIKr,]LU-F390H\$FN8&+Uh@FND(8)қPg`/TZ+Y[[KmPY,{
5wΎ>53mV76fEk%5=*r࣑WT\\P
_Ajuo0T>[MT\\\"\000o;վiT+Em2]@гЯ=VnK_6+NjHx{+Yj՚9Ǡ\"D'FxZnzuDBtHLjIK
y/o
CżtTYo9\t+Vv5(AJyUZ-{k|\t:*/^6jاl˴rPkZ
-R(>\$低WjO%7H/J곧-dPi͏`!+sA\$
Vrn#(^%'IDA=Lb4eYh2/\\ۅ[V|}!Ƞ6Ips³ΙR_4_et'h&%_бpIzM'74R\$|\t/ic3ܯJQ{T66Gw?yGO<cӁբuxV*kM69\$\"IHnyD^Z\t &J6^&¿\000B^]U\t@S+\\}o1#Mi+\"`.IEZMPl)\tq񶻰[DGHaKZd5ul+SN/
%M.b5h5X:YIZ-\tyV~۽j|m.|{t!3׃`?K0^l/Ƌbx1^l/Ƌbx1^Ƌb0^ņb0^ņb/6xa/6xa/Ƌ
x1^l/Ƌbx1^l/Ƌbx1^Ƌb0^Ƌb0^ņb/6x1ņb/6xa/Ƌ
xa/Ƌ
x1^l/Ƌbx1^l/Ƌbx1^Ƌb0^ņb0^ņb/6A`/l!ÿb0\000+g˟^P\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/fp-wien/assets/banner3.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/fp-wien/assets/banner3.png", "/var/www/mautic-ktn/themes/fp-wien/assets/banner3.png");
    }
}
